@@ -1,11 +1,10 @@
 import os
-from investing_algorithm_framework.configuration.settings import Config
-from investing_algorithm_framework.configuration.validator import \
-    ConfigValidator
-from investing_algorithm_framework.configuration.setup import create_app, \
-    setup_config, setup_database, setup_logging
+
 from investing_algorithm_framework.configuration.constants import \
     RESOURCES_DIRECTORY, LOG_LEVEL
+from investing_algorithm_framework.configuration.settings import Config
+from investing_algorithm_framework.configuration.setup import create_app, \
+    setup_config, setup_database, setup_logging
 
 BASE_DIR = os.path.dirname(os.path.abspath(__file__))
 
@@ -13,7 +12,6 @@ BASE_DIR = os.path.dirname(os.path.abspath(__file__))
 __all__ = [
     "Config",
     "BASE_DIR",
-    "ConfigValidator",
     "create_app",
     "setup_database",
     "setup_config",
