@@ -1,18 +1,17 @@
-import os
-
-from enum import Enum
 import logging
+import os
+from enum import Enum
 
-from investing_algorithm_framework.core import OperationalException
 from investing_algorithm_framework.configuration.constants import \
     DATABASE_NAME, DATABASE_DIRECTORY_PATH, RESOURCES_DIRECTORY
+from investing_algorithm_framework.core import OperationalException
 
 logger = logging.getLogger(__name__)
 
 
 class Environment(Enum):
     """
-    Class TimeUnit: Enum for data base type
+    Class TimeUnit: Enum for data_provider base type
     """
     DEV = 'DEV'
     PROD = 'PROD'
@@ -55,8 +54,8 @@ class Environment(Enum):
 
 
 class Config(dict):
-    ENV = "DEV"
-    LOG_LEVEL = 'INFO'
+    ENV = "PROD"
+    LOG_LEVEL = 'DEBUG'
     APP_DIR = os.path.abspath(os.path.dirname(__file__))
     PROJECT_ROOT = os.path.abspath(os.path.join(APP_DIR, os.pardir))
     DEBUG_TB_INTERCEPT_REDIRECTS = False
@@ -77,7 +76,8 @@ class Config(dict):
         DATABASE_NAME: os.getenv(DATABASE_NAME, "database"),
         DATABASE_DIRECTORY_PATH: os.getenv(DATABASE_DIRECTORY_PATH)
     }
-    SCHEDULER_API_ENABLED: True
+    SCHEDULER_API_ENABLED = True
+    CHECK_PENDING_ORDERS = True
 
     def __init__(self):
         super().__init__()
@@ -170,7 +170,7 @@ class Config(dict):
 
         for attribute_key in dictionary:
 
-            if attribute_key.isupper():
+            if attribute_key:
                 config.set(attribute_key, dictionary[attribute_key])
                 config[attribute_key] = dictionary[attribute_key]
         return config
@@ -182,6 +182,7 @@ class TestConfig(Config):
     DATABASE_CONFIG = {
         'DATABASE_NAME': "test",
     }
+    LOG_LEVEL = "INFO"
 
 
 class DevConfig(Config):
@@ -189,3 +190,4 @@ class DevConfig(Config):
     DATABASE_CONFIG = {
         'DATABASE_NAME': "dev",
     }
+    LOG_LEVEL = "INFO"
