@@ -1,28 +1,22 @@
 from abc import abstractmethod, ABC
 
-from investing_algorithm_framework.core.models import Order, OrderStatus
 from investing_algorithm_framework.core.identifier import Identifier
+from investing_algorithm_framework.core.models import Order
 
 
 class OrderExecutor(ABC, Identifier):
 
-    def initialize(self, algorithm_context):
+    def initialize(self, algorithm_context, throw_exception=True):
         pass
 
     @abstractmethod
-    def execute_limit_order(
+    def execute_order(
         self, order: Order, algorithm_context, **kwargs
-    ) -> bool:
+    ) -> Order:
         raise NotImplementedError()
 
     @abstractmethod
-    def execute_market_order(
+    def check_order_status(
         self, order: Order, algorithm_context, **kwargs
-    ) -> bool:
-        raise NotImplementedError()
-
-    @abstractmethod
-    def get_order_status(
-        self, order: Order, algorithm_context, **kwargs
-    ) -> OrderStatus:
+    ) -> Order:
         raise NotImplementedError()
