@@ -1,9 +1,9 @@
-from .order_validator import OrderValidator
 from .default_order_validator import DefaultOrderValidator
+from .order_validator import OrderValidator
 
 
 class OrderValidatorFactory:
 
     @staticmethod
-    def of(broker) -> OrderValidator:
+    def of(market) -> OrderValidator:
         return DefaultOrderValidator()
