@@ -89,7 +89,7 @@ class Strategy:
         algorithm.add_strategy(self)
 
     def add_to_scheduler(self, app_scheduler: APScheduler):
-        if TimeUnit.SECONDS.equals(self.time_unit):
+        if TimeUnit.SECOND.equals(self.time_unit):
             app_scheduler.add_job(
                 id=self.worker_id,
                 name=self.worker_id,
